/**************************************************************************************************
* File: AM2302.c
* File Type: C - Source Code File
* Company: (c) mikroElektronika, 2015
* Revision History:
*       - initial release (DB & PT);
* Description:
*     Flame click is a fire detection solution. It carries a PT334-6B silicon phototransistor thats covered in black epoxy 
*     and therefore sensitive only to infrared light. To use it as a fire alarm, set up the exact detection threshold through 
*     the onboard potentiometer (once reached, the click will send an interrupt to the target board MCU through the mikroBUS INT pin).
*     Othewise the sensor can also output a continuous analog signal through the mikroBUS AN pin. 
*     Flame click can use both a 3.3V or a 5V power supply.
* Test configuration:
*     MCU:             STM32F107VC
*                      http://www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/DATASHEET/CD00220364.pdf
*     Dev.Board:       EasyMx PRO v7 for STM32(R) ARM(R)
*                      http://www.mikroe.com/easymx-pro/stm32/
*     Oscillator:      HSE-PLL, 72.000MHz
*     SW:              mikroC PRO for ARM
*                      http://www.mikroe.com/mikroc/arm/
* NOTES:
*     - Insert Flame Click in mikroBUS socket 1
*     - Turn ON USB UARTA switches (SW12.1 and SW12.2).
*     - For UART communication use USB UART A port at 56000bps
**************************************************************************************************/

#include "resources.h"

// TFT module connections
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8;
sbit TFT_RS at GPIOE_ODR.B12;
sbit TFT_CS at GPIOE_ODR.B15;
sbit TFT_RD at GPIOE_ODR.B10;
sbit TFT_WR at GPIOE_ODR.B11;
sbit TFT_BLED at GPIOE_ODR.B9;
// End TFT module connections

// AM2302 module connections
//sbit FLAME_Out at GPIOD_ODR.B10;
sbit FLAME_In at GPIOD_IDR.B10;
// END AM2302 module connections

void InitDisplay(){
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_BLED = 1;
  TFT_Set_Pen(CL_WHITE, 1);
  TFT_Set_Brush(1,CL_WHITE,0,0,0,0);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);

  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_Black, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_LIne(20,  46, 300,  46);
  TFT_Set_Font(&HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("Flame Click", 105, 14);
  TFT_Set_Font(&Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyMx PRO v7 for STM32", 19, 223);
  TFT_Set_Font(&Verdana12x13_Regular, CL_RED, FO_HORIZONTAL);
  TFT_Write_Text("www.mikroe.com", 200, 223);
  TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
}


void main(){
unsigned int adc_result;
char txt[6];

       InitDisplay();

       GPIO_Analog_Input(&GPIOA_IDR, _GPIO_PINMASK_4);        // Set GPIOA pin 4 as analog input
       GPIO_Digital_Input(&GPIOD_BASE, _GPIO_PINMASK_10);     // Set GPIOD pin 10 as digital input

       UART1_Init(56000);                                     // Initialize UART module at 56000 bps
       Delay_ms(100);                                         // Wait for UART module to stabilize

       UART1_Write_Text("Start");                             // Send Start to UART port
       UART1_Write(13);
       UART1_Write(10);
        
       ADC_Set_Input_Channel(_ADC_CHANNEL_4);                 // Set input ADC channel 4
       ADC1_Init();                                           // ADC module initialization

       while(1){
                 if (GPIOD_IDR.B10)                           // If FLAME is detected!!!
                        { 
                        TFT_Set_Pen(CL_WHITE, 1);
                        TFT_Set_Brush(1, CL_WHITE, 0, LEFT_TO_RIGHT, CL_WHITE, CL_WHITE);
                        TFT_Rectangle(70,60,240,90);
                        TFT_Image_Jpeg(130, 100, FlamePhoto_jpg);   // Print flame jpg picture on display
                        TFT_Set_Font(&TFT_defaultFont, CL_RED, FO_HORIZONTAL);
                        TFT_Write_Text("Flame Detected!",115,65);
                        }
                     else                                     // If there is no FLAME.
                        {
                        TFT_Set_Pen(CL_WHITE, 1);
                        TFT_Set_Brush(1, CL_WHITE, 0, LEFT_TO_RIGHT, CL_WHITE, CL_WHITE);
                        TFT_Rectangle(70,60,240,210);         // Clear text and flame picture
                        TFT_Set_Font(&TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
                        TFT_Write_Text("No Flame",130,65);
                        }
                 adc_result = ADC1_Get_Sample(4);             // Get ADC value from PC3 pin
                 WordToStr(adc_result, txt);                  // Conversion to string
                 UART1_Write_Text(txt);                       // Sending ADC data to UART
                 UART1_Write(13);
                 UART1_Write(10);
                 Delay_ms(350);                               // Small delay
                 }
}